@@ -1,3 +1,3 @@
 from .binary_uuid import BinaryUUID
 from .abstract_model import BaseModal
-from .func_date import convert_date_to_timestamp
+from .func_date import convert_date_to_timestamp, get_timestamp_now
